傲慢与偏见 (豆瓣)
Description: 傲慢与偏见电影简介和剧情介绍,傲慢与偏见影评、图片、预告片、影讯、论坛、在线购票
Keywords: 傲慢与偏见,Pride & Prejudice,傲慢与偏见影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.138豆瓣电影Top250

# 傲慢与偏见 Pride & Prejudice (2005)

导演: 乔·赖特
编剧: 简·奥斯汀 / 黛博拉·莫盖茨
主演: 凯拉·奈特莉 / 马修·麦克费登 / 唐纳德·萨瑟兰 / 布兰达·布莱斯 / 凯瑞·穆里根 / 裴淳华 / 吉娜·马隆 / 妲露拉·莱莉 / 朱迪·丹奇 / 西蒙·伍兹 / 克劳迪·布莱克利 / 汤姆·霍兰德 / 鲁伯特·弗兰德 / 凯利·蕾莉 / 皮普·托伦斯 / 西妮德·马修斯 / 佩内洛普·威尔顿 / 塔姆金·莫钦特
类型: 剧情 / 爱情
制片国家/地区: 法国 / 英国 / 美国
语言: 英语
上映日期: 2005-09-16(英国)
片长: 129 分钟 / 135 分钟(加拿大)
又名: 傲慢与偏见2005 / Pride And Prejudice
IMDb: tt0414387
豆瓣评分
引用
8.7
752053人评价
5星
47.5%
4星
40.7%
3星
10.9%
2星
0.8%
1星
0.2%
好于 98% 爱情片
好于 97% 剧情片
想看 看过
评价:
推荐

## 傲慢与偏见的剧情简介 · · · · · ·

根据简·奥斯汀同名小说改编。伊丽莎白·班纳特(凯拉·奈特丽 饰)出身于小地主家庭，有四个姐妹，母亲班纳特太太整天操心着为女儿物色称心如意的丈夫。新来的邻居宾格来先生和他的朋友达西（马修·麦克菲迪恩 饰）打破了她们一家人单调的乡村生活。宾格来和伊丽莎白的姐姐简·班纳特互生情愫；达西对善良聪明的伊丽莎白产生了好感，而伊丽莎白却对达西不可一世的傲慢心存偏见，不接受他的感情。然而，世事难料，宾格来和简·班纳特因为误会，关系危在旦夕；达西的种种作为，展示了性格中和伊丽莎白相同的善良一面，逐渐赢得了伊丽莎白的好感。两对有情人能否终成眷属？班纳特姐妹们能否得到自己想要的生活？
简·奥斯汀笔下十九世纪初英国乡村生活和社会风貌，重新展现在大银幕上。 ©豆瓣

## 傲慢与偏见的演职员 · · · · · · ( 全部 45 )

- 乔·赖特 导演
- 凯拉·奈特莉 饰 Elizabeth Bennet
- 马修·麦克费登 饰 Mr. Darcy
- 唐纳德·萨瑟兰 饰 Mr. Bennet
- 布兰达·布莱斯 饰 Mrs. Bennet
- 凯瑞·穆里根 饰 Kitty Bennet

## 傲慢与偏见的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1376 · 添加 )

## 傲慢与偏见的获奖情况 · · · · · · ( 全部 )

- 第78届奥斯卡金像奖
- 最佳女主角(提名)
- 凯拉·奈特莉

- 第63届金球奖
- 电影类 最佳音乐/喜剧片(提名)

- 第59届英国电影学院奖
- 电影奖 最佳英国影片(提名)
- 埃里克·菲尔纳 / 乔·赖特 / 蒂姆·贝文 / 保罗·韦伯斯特 / 黛博拉·莫盖茨

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  爱在黎明破晓前

  恋恋笔记本

  重庆森林

  泰坦尼克号

  乱世佳人

  花样年华

  天使爱美丽

  真爱至上

  爱乐之城

我要写短评

## 傲慢与偏见的短评 · · · · · · ( 全部 163859 条 )

热门 / 最新 / 好友

### 6583 有用 原 子 看过 2006-05-01 23:57:01

这达西先生是痴呆不是傲慢吧……

### 6299 有用 露娜peace 看过 2006-06-12 10:16:02

最爱~~~伊丽莎白在大雾中看到渐渐清晰向自己走来的达西先生，我眼睛都湿润了……

### 3673 有用 桃桃林林 看过 2012-07-02 20:39:13

乔·怀特对长镜头有种奇怪的迷恋，总会用那么一两处调度极其复杂的长镜头。美术真棒，布景超华丽，外景也漂亮，摄影很美。情绪很饱满，有几处细节很用心。当然，对于原著党来说，她们是永远不会满意的

### 2247 有用 jj73浅之 看过 2009-06-14 16:07:19

真受不鸟凯拉奈特莉狰狞的笑容

### 1566 有用 Q。 看过 2008-05-18 01:14:11

喜欢导演对光线的运用，很多时候特别唯美。那个时代表达爱情的方式含蓄中有热烈，两人间保持着礼节的距离，目光却可以表达纯净、真挚的情感。片中温馨，平和的氛围，宛如一杯午后红茶，音乐也相当不错。但始终更喜欢BBC版。★★★☆

> 更多短评 163859条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 傲慢与偏见的影评 · · · · · · ( 全部 2370 条 )

热门 / 最新 / 好友
icancu 2008-07-13 04:17:27

## 别担心世上没有人能配上你

等什么时候，每一个女人都完全不用考虑掩示自己的优秀了，再跟我提男女平等。 这么多年过去，人们择偶的标准还是一点没变。焦大喜欢上林妹妹，是个冷笑话。换林妹妹喜欢上焦大？不可能。为什么不可能？就是不可能。从古至今由中而外人们在择偶机能上无一例外地存在着一个隐性渴... (展开)
5821 370 475回应 收起
张樾 2008-01-31 20:09:34

## 无辜

这篇影评可能有剧透

两百年前，简在明亮的碳白色窗台旁，用沾着黑色墨水的羽毛笔写下了当时伦敦以北德比郡的风光： 太阳在低低的云层里穿行，风卷着北大西洋空气中的寒意，那些浮着落叶的溪水，湿润的草场，零落的树木和丘陵，被雨水冲刷之后，微微泛着清新的亮绿。 两百年之后，作为一个身处英伦... (展开)
2903 82 188回应 收起
支离疏 2005-12-28 14:39:18

## Joe Wright的傲慢与偏见

这篇影评可能有剧透

今天，总算在《傲慢与偏见》下档前，去了电影院，150人的小厅居然坐得满满的，考虑到这部文艺片都放了一个多月，使我不禁又多了几分期待。环顾四周，都是些老头老太，大概就我们几个是40岁以下的，就又感慨了一下自己“未熟先烂”，大概心理年龄已经年过半百了。 （1）选角 先... (展开)
1098 243 244回应 收起
周星星 2006-08-30 20:20:51

## 别拿经典开刷

看完了翻拍的电影版《傲慢与偏见》，很难不把它和BBC经典版的《傲慢与偏见》相比较。暂且不论新版的莉齐那一排一笑就经常狂野的外露的牙齿，本应冷漠的达西先生却热情如火的眼神，单单是贝内特先生那一头《加勒比海盗》似的头发，毫无睿智只有粗蛮的形象就令我生厌。贝内特太... (展开)
490 95 188回应 收起
fullflower 2006-01-23 09:07:47

## 又一场《P&P》

小城市电影档期都要慢一步，新版的《P&P》这个周末才上片。本来觉得这么文艺腔的电影，票一定好买，不慌不忙地在开场三十分钟之前赶去影院，居然只剩最后一个位置了。看来这个世界的所有角落，最不能低估的就是作为文学女青年这一群体的数量。要说我真是替Jane Austen的生不逢... (展开)
395 45 100回应 收起
玑衡 2011-02-07 03:26:41

## 在傲慢与偏见的悬崖

你知道如何去傲慢与偏见的悬崖？ 方法如下：到曼彻斯特火车站，乘上一部到希望谷的火车，在石南贤者站下车，走过饥饿巷右转，一路上坡，走一个半小时，能走到石岩山的山脚下。绵延数十里的山脉，将周遭的山谷都茫茫地包围着。这时可千万不能喘歇，英国的白日，到下午四点就全... (展开)
446 21 42回应 收起
Ceiling 2009-06-18 21:11:26

## 难得一见

2013年9月7日加注： 本文在四年前写就时，我情绪相当愤激，因此文中语气激烈，容易影响读者情绪：赞同观点者拍手称快，不赞同者极为反感。读者的这种情绪其实也经常导致不能真正读文章，因此在批驳时也没有真正的对话。 对于这种现象，作者的写作态度和写作情绪是应当... (展开)
345 130 249回应 收起
ys 2007-10-12 01:33:34

## 幸福的家庭究竟是怎样的呢

虽然有评论说这个电影完全没把书的精髓拍出来，我倒是看得瞒HI的，有点捡到宝的感觉。当时挑这个片子只是因为女主角脸蛋很熟（但是想不起是谁）的关系而已。反正书，，，我早就全忘记光了 男主角从出场开始，就闷骚着一张脸，我在心里暗骂一句，靠，闷骚美男嘛。在缓慢的登场... (展开)
224 53 105回应 收起
美味苏苏 2006-01-09 14:54:11

## 难以超越95年经典版本

傲慢与偏见，2005年新版。我知道它不会比95年Colin Firth版本（实际上这是个迷你电影型TV Series）更为经典，当然，服装更美丽了，彭伯利更华丽了；Miss Elizabeth Bennet由Keira Knightley出演，她很漂亮，比Jennifer Ehle漂亮很多，然而这个角色对她来说太稳重了些，她适合那... (展开)
117 24 48回应 收起
豆小喵er 2006-07-21 02:51:40

## Marry a Man Named Darcy

他出场时，走在众人的中间，即使是在热闹的舞会上，也目不斜视，没有一丝笑容，甚至不发一言，骄傲的如同王子一般。他不和任何人跳舞，声称没有合适的舞伴，如此出言不慎，伤害了女孩敏感的心。但在女孩踏上马车的一霎那，他伸出手握住了女孩的小手，扶着她上了车，然后简短道... (展开)
190 20 15回应 收起

> 更多影评 2370篇

添加新讨论

## 讨论区 · · · · · ·

达西做了什么好事让伊丽莎白改观 | 来自嘿是这傻啊 | 1 回应 | 2022-11-23 14:48:00
也太像奥兰多布鲁姆了吧？？？？脸盲差点没分出来 | 来自domz分钟 | 16 回应 | 2022-11-22 17:03:52
求135min的资源 | 来自碗里不是白米饭 | 5 回应 | 2022-11-17 00:27:17
原来Jane是《消失的爱人》女主 | 来自Rene灰机 | 17 回应 | 2022-11-12 08:56:25
05版被删的结局！ | 来自Midori | 45 回应 | 2022-11-12 02:29:07

> 去这部影片的讨论区（全部416条）

## 关于《傲慢与偏见》的问题 · · · · · · ( 全部22个 )

- 达西是从什么时候爱上她的呢？ 11人回答
- 伊丽莎白为什么喜欢上达西？ 6人回答

> 全部22个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

## 谁在看这部电影 · · · · · ·

- 呼图壁河
  刚刚 看过
- whcwhcwhc
  2分钟前 看过
- 再见白丝
  3分钟前 想看

1274790人看过 / 310678人想看

订阅傲慢与偏见的评论:
feed: rss 2.0